LinkProcessingMode enum

How SdkCore should process incoming / deferred links.

Inheritance
Available extensions

Values

all → const LinkProcessingMode
const LinkProcessingMode('all')
webOnly → const LinkProcessingMode
const LinkProcessingMode('webOnly')
deferredOnly → const LinkProcessingMode
const LinkProcessingMode('deferredOnly')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wireValue → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromWire(String? value) → LinkProcessingMode

Constants

values → const List<LinkProcessingMode>
A constant List of the values in this enum, in order of their declaration.