MethodChannelNativeBridge class
Production bridge: MethodChannel + EventChannel → Android/iOS SdkCore.
- Implemented types
Constructors
- MethodChannelNativeBridge({MethodChannel? methodChannel, EventChannel? eventChannel})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
configure(
{required String clientId, required String publicKeyId, required SdkOptions options}) → Future< void> -
override
-
consume(
String linkId) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
observeLinks(
) → Stream< DeferredLink> -
override
-
resolveDeferred(
) → Future< DeferredLink?> -
override
-
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited