NativeBridge class abstract
Flutter adapters/native-bridge — MethodChannel facade → native SdkCore.
App / sample Dart code must depend on TaqlynSdk only — never Play Install Referrer / UIPasteboard types.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
configure(
{required String clientId, required String publicKeyId, required SdkOptions options}) → Future< void> -
consume(
String linkId) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
observeLinks(
) → Stream< DeferredLink> -
resolveDeferred(
) → Future< DeferredLink?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited