ShareClient class

Thin HTTP wrapper for POST /v1/sdk/short-links (stdlib HttpClient).

Constructors

ShareClient({HttpClient? httpClient})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create({required ShareSession session, String? destinationPath, String? destinationWeb, Map<String, String>? params, String? ogTitle, String? ogDescription, String? ogImage}) → Future<ShareLink>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited