ShareSession class

Session remembered from TaqlynSdk.configure for in-app share create.

Constructors

ShareSession({required String clientId, required String publicKeyId, String? env})
const

Properties

clientId → String
final
env → String?
final
hashCode → int
The hash code for this object.
no setterinherited
publicKeyId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited